<?php

declare(strict_types=1);

namespace Drupal\navigation_plus;

/**
 * Interface for tool plugins.
 */
interface ModeInterface {

  /**
   * Returns the translated plugin label.
   */
  public function label(): string;

  /**
   * Add attachments.
   *
   * @param array $attachments
   *   The #attached array from $variables.
   *
   * @return void
   */
  public function addAttachments(array &$attachments): void;

  /**
   * Applies
   *
   * @return bool
   *   Whether the tool plugin works on this type of entity.
   */
  public function applies(): bool;

  /**
   * Get icon path.
   *
   * @return string
   *   The absolute path to the mode's toggle button icon.
   */
  public function getIconPath(): string;

  /**
   * Build toolbar items.
   *
   * Adds a toolbar to the navigation module's render array. When you toggle
   * into your mode the toolbar is revealed in place of the navigation modules
   * toolbar.
   *
   * @param array $variables
   *   The navigation modules toolbar render array.
   * @param \Drupal\navigation_plus\ModeInterface $mode
   *    The mode plugin.
   *
   * @return array
   *   An array of navigation sidebar items.
   *
   * @see \Drupal\navigation_plus\Plugin\Mode\Edit
   */
  public function buildToolbarItems(array &$variables, ModeInterface $mode): array;

  /**
   * Build top and side bars.
   *
   * @param array $page_top
   *   The page top render array.
   * @param \Drupal\navigation_plus\ModeInterface $mode
   *   The mode plugin.
   *
   * @return void
   */
  public function buildBars(array &$page_top, ModeInterface $mode): void;

}
